@@ -12,6 +12,9 @@ public:
     readerView(QTextDocument *document, QWidget *parent);
     void viewpage(int whichpage);
     QAbstractTextDocumentLayout::PaintContext ctx;
+    int interPageSpacing[2];//0:R/T/L;1:B;
+    void setDoc(QTextDocument *rdoc);
+    QTextDocument * getDoc(){return doc;};
 
 protected:
     virtual void paintEvent(QPaintEvent *e);
@@ -21,7 +24,6 @@ private:
     void paintPage(QPainter *painter, int page);
     QTextDocument *doc;
     qreal scale;
-    int interPageSpacing;
     int page;
     QRectF viewRect;
 signals:
